@@ -71,6 +71,14 @@ namespace Gwenview {
 
 const char* CONFIG_SAVE_AUTOMATICALLY="save automatically";
 
+
+/**
+ * Returns a widget suitable to use as a dialog parent
+ */
+static QWidget* dialogParentWidget() {
+	return KApplication::kApplication()->mainWidget();
+}
+
 //-------------------------------------------------------------------
 //
 // DocumentPrivate
@@ -81,6 +89,7 @@ public:
 	KURL mURL;
 	bool mModified;
 	QImage mImage;
+	QString mMimeType;
 	QCString mImageFormat;
 	DocumentImpl* mImpl;
 	QGuardedPtr<KIO::StatJob> mStatJob;
@@ -134,6 +143,14 @@ Document::~Document() {
 // Properties
 //
 //---------------------------------------------------------------------
+QString Document::mimeType() const {
+	return d->mMimeType;
+}
+
+void Document::setMimeType(const QString& mimeType) {
+	d->mMimeType = mimeType;
+}
+
 MimeTypeUtils::Kind Document::urlKind() const {
 	return d->mImpl->urlKind();
 }
@@ -229,15 +246,13 @@ const QImage& Document::image() const {
 	return d->mImage;
 }
 
-void Document::setImage(QImage img, bool update) {
+void Document::setImage(QImage img) {
 	bool sizechange = d->mImage.size() != img.size();
-	d->mImage=img;
-	if( update ) {
-		if( sizechange ) emit sizeUpdated( img.width(), img.height());
-		emit rectUpdated(QRect(QPoint(0,0), img.size()) );
-	}
+	d->mImage = img;
+	if( sizechange ) emit sizeUpdated();
 }
 
+
 KURL Document::dirURL() const {
 	if (filename().isEmpty()) {
 		return d->mURL;
@@ -290,6 +305,14 @@ int Document::fileSize() const {
 	return d->mFileSize;
 }
 
+bool Document::canBeSaved() const {
+	return d->mImpl->canBeSaved();
+}
+
+bool Document::isModified() const {
+	return d->mModified;
+}
+
 void Document::slotLoading() {
 	BusyLevelManager::instance()->setBusyLevel( this, BUSY_LOADING );
 }
@@ -393,7 +416,7 @@ void Document::doPaint(KPrinter *printer, QPainter *painter) {
 
 
 		if (size.width() > pdWidth || size.height() > pdHeight) {
-			int resp = KMessageBox::warningYesNoCancel(0,
+			int resp = KMessageBox::warningYesNoCancel(dialogParentWidget(),
 				i18n("The image will not fit on the page, what do you want to do?"),
 				QString::null,KStdGuiItem::cont(),
 				i18n("Shrink") );
@@ -456,7 +479,7 @@ void Document::transform(ImageUtils::Orientation orientation) {
 void Document::save() {
 	QString msg=saveInternal(url(), d->mImageFormat);
 	if (!msg.isNull()) {
-		KMessageBox::error(0, msg);
+		KMessageBox::error(dialogParentWidget(), msg);
 	}
 }
 
@@ -464,13 +487,13 @@ void Document::save() {
 void Document::saveAs() {
 	KURL saveURL;
 
-	ImageSaveDialog dialog(saveURL, d->mImageFormat, 0);
+	ImageSaveDialog dialog(saveURL, d->mImageFormat, dialogParentWidget());
 	dialog.setSelection(url().fileName());
 	if (!dialog.exec()) return;
 
 	QString msg=saveInternal(saveURL, dialog.imageFormat() );
 	if (!msg.isNull()) {
-		KMessageBox::error(0, msg);
+		KMessageBox::error(dialogParentWidget(), msg);
 	}
 }
 
@@ -480,7 +503,7 @@ void Document::saveBeforeClosing() {
 	QString msg=i18n("<qt>The image <b>%1</b> has been modified, do you want to save the changes?</qt>")
 		.arg(url().prettyURL());
 
-	int result=KMessageBox::questionYesNo(0, msg, QString::null,
+	int result=KMessageBox::questionYesNo(dialogParentWidget(), msg, QString::null,
 		KStdGuiItem::save(), KStdGuiItem::discard(), CONFIG_SAVE_AUTOMATICALLY);		
 
 	if (result == KMessageBox::Yes) {
@@ -505,8 +528,8 @@ void Document::switchToImpl(DocumentImpl* impl) {
 
 	connect(d->mImpl, SIGNAL(finished(bool)),
 		this, SLOT(slotFinished(bool)) );
-	connect(d->mImpl, SIGNAL(sizeUpdated(int, int)),
-		this, SIGNAL(sizeUpdated(int, int)) );
+	connect(d->mImpl, SIGNAL(sizeUpdated()),
+		this, SIGNAL(sizeUpdated()) );
 	connect(d->mImpl, SIGNAL(rectUpdated(const QRect&)),
 		this, SIGNAL(rectUpdated(const QRect&)) );
 	d->mImpl->init();
