@@ -89,27 +89,24 @@ void DocumentLoadingImpl::init() {
 	connect( d->mLoader, SIGNAL( urlKindDetermined()), SLOT( slotURLKindDetermined() ));
 	connect( d->mLoader, SIGNAL( sizeLoaded( int, int )), SLOT( sizeLoaded( int, int )));
 	connect( d->mLoader, SIGNAL( imageChanged( const QRect& )), SLOT( imageChanged( const QRect& )));
-	connect( d->mLoader, SIGNAL( frameLoaded()), SLOT( frameLoaded()));
 	connect( d->mLoader, SIGNAL( imageLoaded( bool )), SLOT( imageLoaded( bool )));
 
 	// it's possible the loader already has the whole or at least part of the image loaded
-	QSize s = d->mLoader->knownSize();
-	if( !s.isEmpty()) {
+	QImage image = d->mLoader->processedImage();
+	if (!image.isNull()) {
 		if( d->mLoader->frames().count() > 0 ) {
-			setImage( d->mLoader->frames().first().image, false );
-			emit sizeUpdated( s.width(), s.height());
-			emit rectUpdated( QRect( QPoint( 0, 0 ), s ));
+			setImage( d->mLoader->frames().first().image);
+			emitImageRectUpdated();
 		} else {
-			setImage( d->mLoader->processedImage(), false );
-			emit sizeUpdated( s.width(), s.height());
+			setImage(image);
 			QMemArray< QRect > rects = d->mLoader->loadedRegion().rects();
 			for( unsigned int i = 0; i < rects.count(); ++i ) {
-				emit rectUpdated( rects[ i ] );
+				emit rectUpdated(rects[i]);
 			}
 		}
 	}
-	if( d->mLoader->completed()) emit imageLoaded( d->mLoader->frames().count() != 0 );
-	// this may be deleted here
+	if( d->mLoader->completed()) imageLoaded( d->mLoader->frames().count() != 0 );
+	// 'this' may be deleted here
 }
 
 
@@ -132,6 +129,7 @@ void DocumentLoadingImpl::imageLoaded( bool ok ) {
 		return;
 	}
 	setImageFormat( format );
+	setMimeType(d->mLoader->mimeType());
 
 	// Update file info
 	setFileSize(d->mLoader->rawData().size());
@@ -148,22 +146,20 @@ void DocumentLoadingImpl::imageLoaded( bool ok ) {
 
 
 void DocumentLoadingImpl::imageChanged(const QRect& rect) {
-	if( d->mLoader->frames().count() > 0 ) return;
-	setImage(d->mLoader->processedImage(), false);
-	emit rectUpdated( rect );
+	LOG(rect);
+	setImage(d->mLoader->processedImage());
+	emit rectUpdated(rect);
 }
 
-void DocumentLoadingImpl::frameLoaded() {
-	if( d->mLoader->frames().count() == 1 ) {
-		// explicit sharing - don't modify the image in document anymore
-		setImage( d->mLoader->frames().first().image.copy(), false ); 
-	}
-}
 
 void DocumentLoadingImpl::sizeLoaded(int width, int height) {
 	LOG(width << "x" << height);
-	setImage( d->mLoader->processedImage(), false);
-	emit sizeUpdated(width, height);
+	// Silence compiler
+	width=width;
+	height=height;
+
+	setImage(d->mLoader->processedImage());
+	emit sizeUpdated();
 }
 
 } // namespace
