@@ -1,7 +1,7 @@
 /*
  * qxcfi.cpp: A Qt 3 plug-in for reading GIMP XCF image files
  * Copyright (C) 2001 lignum Computing, Inc. <allen@lignumcomputing.com>
- * $Id: qxcfi.cpp 456881 2005-09-03 23:23:22Z gateau $
+ * $Id: qxcfi.cpp 531593 2006-04-19 15:46:52Z gateau $
  *
  * This plug-in is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -2400,10 +2400,6 @@ void XCFImageFormat::dissolveAlphaPixels ( QImage& image, int x, int y )
   }
 }
 
-#if KDE_IS_VERSION(3, 3, 89)
 KDE_Q_EXPORT_PLUGIN( XCFImageFormat )
-#else
-Q_EXPORT_PLUGIN( XCFImageFormat )
-#endif
 
 } // namespace
